@@ -6,11 +6,11 @@ import time
 
 from .config import LOCAL_PATH
 from .core import (AdditionOperator, CompositionOperator, DiagonalOperator,
-                   HomothetyOperator, Operator, ReverseOperatorFactory, _pool)
+                   HomothetyOperator, Operator, _pool)
 from .decorators import (aligned, contiguous, inplace, linear, real, square,
                          unitary)
 from .memory import empty
-from .utils import (complex_dtype_for, isalias, openmp_num_threads, product,
+from .utils import (complex_dtype, isalias, openmp_num_threads, product,
                     tointtuple)
 from .utils.ufuncs import multiply_conjugate
 
@@ -30,6 +30,12 @@ except:
 # PRESERVE_INPUT: default except c2r and hc2r
 # DESTROY_INPUT: default for c2r and hc2r, only possibility for multi c2r
 
+OPERATOR_ATTRIBUTES = ['attrin', 'attrout', 'classin', 'classout', 'commin',
+                       'commout', 'reshapein', 'reshapeout', 'shapein',
+                       'shapeout', 'toshapein', 'toshapeout', 'validatein',
+                       'validateout', 'dtype', 'flags']
+
+
 @linear
 @square
 @inplace
@@ -39,7 +45,7 @@ class _FFTWConvolutionOperator(Operator):
     """
     Multi-dimensional convolution by a real or complex kernel,
     using the discrete Fourier transform.
-        
+
     """
     def __init__(self, kernel, shapein, axes=None, fftw_flag='FFTW_MEASURE',
                  nthreads=None, dtype=None, **keywords):
@@ -54,9 +60,9 @@ class _FFTWConvolutionOperator(Operator):
             Axes along which the convolution is performed. Convolution over
             less axes than the operator's input is not yet supported.
         fftw_flag : string
-            list of strings and is a subset of the flags that FFTW allows for 
+            list of strings and is a subset of the flags that FFTW allows for
             the planners. Specifically, FFTW_ESTIMATE, FFTW_MEASURE,
-            FFTW_PATIENT and FFTW_EXHAUSTIVE are supported. These describe the 
+            FFTW_PATIENT and FFTW_EXHAUSTIVE are supported. These describe the
             increasing amount of effort spent during the planning stage to
             create the fastest possible transform. Usually, FFTW_MEASURE is
             a good compromise and is the default.
@@ -78,13 +84,13 @@ class _FFTWConvolutionOperator(Operator):
 
         shapein = tointtuple(shapein)
         if len(shapein) != kernel.ndim:
-            raise ValueError("The kernel dimension '{0}' is incompatible with t"
-                "hat of the specified shape '{1}'.".format(kernel.ndim,
-                len(shapein)))
+            raise ValueError(
+                "The kernel dimension '{0}' is incompatible with that of the s"
+                "pecified shape '{1}'.".format(kernel.ndim, len(shapein)))
 
         # if the kernel is larger than the image, we don't crop it since it
         # might affect normalisation of the kernel
-        if any([ks > s for ks,s in zip(kernel.shape, shapein)]):
+        if any([ks > s for ks, s in zip(kernel.shape, shapein)]):
             raise ValueError('The kernel must not be larger than the input.')
 
         if axes is None:
@@ -97,14 +103,14 @@ class _FFTWConvolutionOperator(Operator):
             n = product(shapein)
             fft = _FFTWComplexForwardOperator(shapein, axes, fftw_flag,
                                               nthreads, dtype, **keywords)
-            kernel_fft = _get_kernel_fft(kernel, shapein, dtype, shapein, dtype,
-                                         fft.oplan)
+            kernel_fft = _get_kernel_fft(kernel, shapein, dtype, shapein,
+                                         dtype, fft.oplan)
             kernel_fft /= n
             self.__class__ = CompositionOperator
             self.__init__([n, fft.H, DiagonalOperator(kernel_fft), fft])
             return
 
-        dtype_ = complex_dtype_for(dtype)
+        dtype_ = complex_dtype(dtype)
         shape_ = self._reshape_to_halfstorage(shapein, axes)
         _load_wisdom()
         aligned = self.flags.aligned_input
@@ -148,7 +154,7 @@ class _FFTWRealConvolutionOperator(Operator):
     Convolution by a real kernel.
     The first argument is the FFT of the real kernel. It is not necessarily
     aligned.
-    
+
     """
     def __init__(self, kernel_fft, fplan, bplan, axes, fftw_flag, nthreads,
                  shapein=None, dtype=None, **keywords):
@@ -160,19 +166,18 @@ class _FFTWRealConvolutionOperator(Operator):
         self.fftw_flag = fftw_flag
 
         Operator.__init__(self, shapein=shapein, dtype=dtype, **keywords)
-        self.set_rule('.T', lambda s: ReverseOperatorFactory(
-                      _FFTWRealConvolutionTransposeOperator, s, s.kernel,
-                      s._fplan, s._bplan, s.axes, s.fftw_flag, s.nthreads))
-        self.set_rule('.{HomothetyOperator}', self._rule_homothety,
-                      CompositionOperator, globals())
-        self.set_rule('.{_FFTWRealConvolutionOperator}', self.
-                      _rule_add_real, AdditionOperator, globals())
-        self.set_rule('.{_FFTWRealConvolutionOperator}', self.
-                      _rule_cmp_real, CompositionOperator, globals())
-        self.set_rule('.{_FFTWComplexBackwardOperator}', self.
-                      _rule_complex_backward, CompositionOperator, globals())
-        self.set_rule('{_FFTWComplexForwardOperator}.', self.
-                      _rule_complex_forward, CompositionOperator, globals())
+        self.set_rule('T', lambda s: _FFTWRealConvolutionTransposeOperator(
+            s.kernel, s._fplan, s._bplan, s.axes, s.fftw_flag, s.nthreads))
+        self.set_rule(('.', HomothetyOperator), self._rule_homothety,
+                      CompositionOperator)
+        self.set_rule(('.', _FFTWRealConvolutionOperator), self.
+                      _rule_add_real, AdditionOperator)
+        self.set_rule(('.', _FFTWRealConvolutionOperator), self.
+                      _rule_cmp_real, CompositionOperator)
+        self.set_rule(('.', _FFTWComplexBackwardOperator), self.
+                      _rule_complex_backward, CompositionOperator)
+        self.set_rule((_FFTWComplexForwardOperator, '.'), self.
+                      _rule_complex_forward, CompositionOperator)
 
     def direct(self, input, output):
         shape = self.kernel.shape
@@ -196,9 +201,9 @@ class _FFTWRealConvolutionOperator(Operator):
         kernel = empty(self.kernel.shape, self.kernel.dtype)
         self.get_kernel(kernel)
         kernel *= scalar.data
-        result = _FFTWRealConvolutionOperator(kernel, self._fplan, self._bplan,
-                     self.axes, self.fftw_flag, self.nthreads, self.shapein,
-                     self.dtype)
+        result = _FFTWRealConvolutionOperator(
+            kernel, self._fplan, self._bplan, self.axes, self.fftw_flag,
+            self.nthreads, self.shapein, self.dtype)
         return result
 
     @staticmethod
@@ -209,9 +214,9 @@ class _FFTWRealConvolutionOperator(Operator):
         kernel = empty(self.kernel.shape, self.kernel.dtype)
         self.get_kernel(kernel)
         np.add(kernel, other.get_kernel(), kernel)
-        result = _FFTWRealConvolutionOperator(kernel, self._fplan, self._bplan,
-                     self.axes, self.fftw_flag, self.nthreads, self.shapein,
-                     self.dtype)
+        result = _FFTWRealConvolutionOperator(
+            kernel, self._fplan, self._bplan, self.axes, self.fftw_flag,
+            self.nthreads, self.shapein, self.dtype)
         return result
 
     @staticmethod
@@ -223,9 +228,9 @@ class _FFTWRealConvolutionOperator(Operator):
         self.get_kernel(kernel)
         kernel *= other.get_kernel()
         kernel *= product(self.shapein)
-        result = _FFTWRealConvolutionOperator(kernel, self._fplan, self._bplan,
-                     self.axes, self.fftw_flag, self.nthreads, self.shapein,
-                     self.dtype)
+        result = _FFTWRealConvolutionOperator(
+            kernel, self._fplan, self._bplan, self.axes, self.fftw_flag,
+            self.nthreads, self.shapein, self.dtype)
         return result
 
     @staticmethod
@@ -234,13 +239,13 @@ class _FFTWRealConvolutionOperator(Operator):
         other.H.direct(kernel, kernel)
         kernel /= product(self.shapein)
         return other, DiagonalOperator(kernel)
-    
+
     @staticmethod
     def _rule_complex_forward(other, self):
         kernel = self._restore_kernel().astype(self.kernel.dtype)
         other.direct(kernel, kernel)
         return DiagonalOperator(kernel), other
-        
+
     def _restore_kernel(self):
         shape = self.kernel.shape
         dtype = self.kernel.dtype
@@ -257,7 +262,7 @@ class _FFTWRealConvolutionOperator(Operator):
 class _FFTWRealConvolutionTransposeOperator(_FFTWRealConvolutionOperator):
     """
     Transpose of the convolution by a real kernel.
-    
+
     """
     __name__ = '_FFTW_RealConvolutionOperator.T'
 
@@ -317,7 +322,7 @@ class _FFTWComplexForwardOperator(_FFTWComplexOperator):
             Axes along which the transform is performed.
         fftw_flag : string
             FFTW flag for the planner: FFTW_ESTIMATE, FFTW_MEASURE,
-            FFTW_PATIENT or FFTW_EXHAUSTIVE. These describe the 
+            FFTW_PATIENT or FFTW_EXHAUSTIVE. These describe the
             increasing amount of effort spent during the planning stage to
             create the fastest possible transform. Usually, FFTW_MEASURE is
             a good compromise and is the default.
@@ -330,11 +335,11 @@ class _FFTWComplexForwardOperator(_FFTWComplexOperator):
         """
         _FFTWComplexOperator.__init__(self, shapein, axes, fftw_flag,
                                       nthreads, dtype, **keywords)
-        self.set_rule('.H', lambda s: 
+
+        self.set_rule('H', lambda s:
                       HomothetyOperator(1 / product(s.shapein)) *
-                      ReverseOperatorFactory(_FFTWComplexBackwardOperator, s,
-                                             forward=s))
-        self.set_rule('{_FFTWComplexBackwardOperator}.', lambda o,s:
+                      _FFTWComplexBackwardOperator(s.shapein, forward=s))
+        self.set_rule((_FFTWComplexBackwardOperator, '.'), lambda o, s:
                       HomothetyOperator(product(s.shapein)),
                       CompositionOperator)
 
@@ -360,12 +365,13 @@ class _FFTWComplexBackwardOperator(_FFTWComplexOperator):
     """
     def __init__(self, shapein, dtype=None, forward=None, **keywords):
 
+        dtype = dtype or forward.dtype
         _FFTWComplexOperator.__init__(self, shapein, forward.axes,
                                       forward.fftw_flag,
                                       forward.nthreads, dtype, **keywords)
-        self.set_rule('.H', lambda s: 
+        self.set_rule('H', lambda s:
                       HomothetyOperator(product(s.shapein)) * forward)
-        self.set_rule('{_FFTWComplexForwardOperator}.', lambda o,s:
+        self.set_rule((_FFTWComplexForwardOperator, '.'), lambda o, s:
                       HomothetyOperator(product(s.shapein)),
                       CompositionOperator)
 
@@ -386,7 +392,7 @@ class _FFTWComplexBackwardOperator(_FFTWComplexOperator):
 
 def _get_kernel_fft(kernel, shapein, dtypein, shapeout, dtypeout, fft):
     with _pool.get(shapein, dtypein) as kernel_padded:
-        ker_slice = [slice(0,s) for s in kernel.shape]
+        ker_slice = [slice(0, s) for s in kernel.shape]
         kernel_padded[...] = 0
         kernel_padded[ker_slice] = kernel
         ker_origin = (np.array(kernel.shape)-1) // 2
@@ -397,11 +403,13 @@ def _get_kernel_fft(kernel, shapein, dtypein, shapeout, dtypeout, fft):
         fft.execute()
         return kernel_fft
 
+
 def _load_wisdom():
     """ Loads the 3 wisdom files. """
     global _is_fftw_wisdom_loaded
     if _is_fftw_wisdom_loaded:
         return
+
     def load(filename):
         try:
             with open(filename) as f:
@@ -409,16 +417,16 @@ def _load_wisdom():
         except IOError:
             wisdom = ''
         return wisdom
-    
+
     wisdom = [load(f) for f in FFTW_WISDOM_FILES]
     pyfftw.import_wisdom(wisdom)
     _is_fftw_wisdom_loaded = True
 
+
 def _save_wisdom():
     """ Save wisdom as 3 files. """
     wisdom = pyfftw.export_wisdom()
     for filename, w in zip(FFTW_WISDOM_FILES, wisdom):
-        print 
         try:
             os.remove(filename)
         except OSError:
@@ -428,6 +436,7 @@ def _save_wisdom():
         with open(filename, 'w') as f:
             f.write(w)
 
+
 # make FFTW the default
 ConvolutionOperator = _FFTWConvolutionOperator
 FFTOperator = _FFTWComplexForwardOperator
