@@ -3,23 +3,97 @@ Implements iterative algorithm class.
 """
 import numpy as np
 from copy import copy
-import pylab
+try:
+    import pylab
+except:
+    pass
 
-from .linesearch import *
-from .criterions import *
+from .linesearch import optimal_step
+from .criterions import norm2, quadratic_criterion, huber_criterion
 
 __all__ = [
-    'Algorithm',
-    'Callback',
     'ConjugateGradient',
     'HuberConjugateGradient',
-    'StopCondition',
     'acg',
     'hacg',
     'fletcher_reeves',
     'polak_ribiere',
 ]
 
+# DEPRECATED
+class Algorithm(object):
+    """
+    Abstract class to define iterative algorithms.
+
+    Attributes
+    ----------
+
+    niterations : int
+        Current iteration number.
+
+    Methods
+    -------
+
+    initialize : Set variables to initial state.
+
+    run : performs the optimization until stop_condition is reached or
+          Ctrl-C is pressed.
+
+    next : perform one iteration and return current solution.
+
+    callback : user-defined function to print status or save variables.
+
+    cont : continue the optimization skipping initialiaztion.
+
+    """
+    def initialize(self):
+        print('The Algorithm class is deprecated.')
+        self.iter_ = 0
+        self.current_solution = None
+
+    def callback(self):
+        pass
+
+    def iterate(self, n=1):
+        """
+        Perform n iterations and return current solution.
+        """
+        for i in xrange(n):
+            self.iter_ += 1
+            self.callback(self)
+        return self.current_solution
+
+    def run(self):
+        """
+        Perform the optimization.
+        """
+        self.initialize()
+        self.iterate() # at least 1 iteration
+        self.cont()
+        self.at_exit()
+        return self.current_solution
+
+    def cont(self):
+        """
+        Continue an interrupted estimation (like call but avoid
+        initialization).
+        """
+        while not self.stop_condition(self):
+            self.iterate()
+        return self.current_solution
+
+    def at_exit(self):
+        """
+        Perform some task at exit.
+        Does nothing by default.
+        """
+        pass
+
+    def __call__(self):
+        print("Deprecation warning: use 'run' method instead.")
+        self.run()
+
+
 # defaults
 TOL = 1e-6
 GTOL = 1e-6
@@ -181,67 +255,6 @@ default_callback = Callback()
 
 # algorithms
 
-class Algorithm(object):
-    """
-    Abstract class to define iterative algorithms.
-
-    Attributes
-    ----------
-
-    iter_ : int
-        Current iteration number.
-
-    Methods
-    -------
-
-    initialize : Set variables to initial state.
-
-    iterate : perform one iteration and return current solution.
-
-    callback : user-defined function to print status or save variables.
-
-    cont : continue the optimization skipping initialiaztion.
-
-    __call__ : performs the optimization until stop_condition is reached.
-
-    """
-    def initialize(self):
-        self.iter_ = 0
-        self.current_solution = None
-    def callback(self):
-        pass
-    def iterate(self):
-        """
-        Perform one iteration and returns current solution.
-        """
-        self.iter_ += 1
-        self.callback(self)
-        # return value not used in loop but usefull in "interactive mode"
-        return self.current_solution
-    def at_exit(self):
-        """
-        Perform some task at exit.
-        Does nothing by default.
-        """
-        pass
-    def __call__(self):
-        """
-        Perform the optimization.
-        """
-        self.initialize()
-        self.iterate() # at least 1 iteration
-        self.cont()
-        self.at_exit()
-        return self.current_solution
-    def cont(self):
-        """
-        Continue an interrupted estimation (like call but avoid
-        initialization).
-        """
-        while not self.stop_condition(self):
-            self.iterate()
-        return self.current_solution
-
 class ConjugateGradient(Algorithm):
     """
     Apply the conjugate gradient algorithm to a Criterion instance.
@@ -393,7 +406,7 @@ def acg(model, data, priors=[], hypers=[], covariances=None, return_algo=False,
                                                stop_condition=stop_condition,
                                                callback=callback,
                                                **kwargs)
-        sol = algorithm()
+        sol = algorithm.run()
         if return_algo:
             return sol, algorithm
         else:
@@ -407,7 +420,7 @@ def hacg(model, data, priors=[], hypers=[], deltas=None, return_algo=False, **kw
                                        stop_condition=stop_condition,
                                        callback=callback,
                                        **kwargs)
-    sol = algorithm()
+    sol = algorithm.run()
     return sol
 
 # other
