@@ -21,8 +21,8 @@ for l in pywt.wavelist():
         rwavelist[l] = l
 
 
-@linear
 @real
+@linear
 class WaveletOperator(Operator):
     def __init__(self, wavelet, mode='zpd', level=None, shapein=None,
                  **keywords):
@@ -64,7 +64,7 @@ class WaveletOperator(Operator):
         shapeout = sum(self.sizes)
         Operator.__init__(self, shapein=shapein, shapeout=shapeout, **keywords)
         if self.wavelet.orthogonal:
-            self.set_rule('.T.', '1', CompositionOperator)
+            self.set_rule('T,.', '1', CompositionOperator)
 
     def direct(self, x, out):
         coeffs = pywt.wavedec(x, self.wavelet, mode=self.mode,
@@ -84,8 +84,8 @@ class WaveletOperator(Operator):
                 for i in xrange(len(self.sizes))]
 
 
-@linear
 @real
+@linear
 class Wavelet2dOperator(Operator):
     def __init__(self, wavelet, mode='zpd', level=None, shapein=None,
                  **keywords):
@@ -134,7 +134,7 @@ class Wavelet2dOperator(Operator):
 
         Operator.__init__(self, shapein=shapein, shapeout=shapeout, **keywords)
         if self.wavelet.orthogonal:
-            self.set_rule('.T.', '1', CompositionOperator)
+            self.set_rule('T,.', '1', CompositionOperator)
 
     def direct(self, x, out):
         coeffs = pywt.wavedec2(x, self.wavelet, mode=self.mode,
