@@ -6,12 +6,11 @@ import sys
 from nose.plugins.skip import SkipTest
 from pyoperators import memory, decorators
 from pyoperators.core import (
-    Operator, AdditionOperator, BroadcastingOperator, BlockColumnOperator,
-    BlockDiagonalOperator, BlockRowOperator, BlockSliceOperator,
-    CompositionOperator, GroupOperator, ConstantOperator, DenseOperator,
-    DiagonalOperator, IdentityOperator, MaskOperator, MultiplicationOperator,
-    HomothetyOperator, ReductionOperator, ZeroOperator, asoperator,
-    _pool as pool, I, O)
+    Operator, AdditionOperator, BlockColumnOperator, BlockDiagonalOperator,
+    BlockRowOperator, BlockSliceOperator, CompositionOperator, GroupOperator,
+    ConstantOperator, DenseOperator, DiagonalOperator, IdentityOperator,
+    MaskOperator, MultiplicationOperator, HomothetyOperator, ReductionOperator,
+    ZeroOperator, asoperator, _pool as pool, I, O)
 from pyoperators.memory import zeros
 from pyoperators.utils import (
     ndarraywrap, first_is_not, operation_assignment, product)
@@ -102,9 +101,14 @@ class Op3(Operator):
         pass
 
 
+class OperatorNIR(Operator):
+    def direct(self, input, output):
+        output[...] = input
+
+
 class OperatorIR(Operator):
     def direct(self, input, output, operation=operation_assignment):
-        pass
+        operation(output, input)
 
 
 #===========
@@ -177,11 +181,29 @@ def test_shape_input_and_output():
         yield func, op.flags, type(op).__name__
 
 
-def test_inplace_reduction():
-    assert not Operator().flags.inplace_reduction
+def test_inplace_reduction1():
+    out = np.zeros(3, dtype=int)
+    assert not OperatorNIR().flags.inplace_reduction
+    assert_raises(ValueError, OperatorNIR(), [1, 0, 0], out,
+                  operation=operator.iadd)
     assert OperatorIR().flags.inplace_reduction
+    assert_raises(ValueError, OperatorIR(), [1, 0, 0], operation=operator.iadd)
 
 
+def test_inplace_reduction2():
+    op = OperatorIR()
+    inputs = [1, 1, 0], [0, 2, 1], [0, 1, 1]
+    expecteds = [0, 1, 1], [2, 5, 3], [0, 2, 0]
+
+    def func(o, e):
+        output = np.ones(3, dtype=int)
+        for i in inputs:
+            op(i, output, operation=o)
+        assert_same(output, e)
+    for o, e in zip((operation_assignment, operator.iadd, operator.imul),
+                    expecteds):
+        yield func, o, e
+
 def test_autoflags():
     def func(f):
         assert_raises(ValueError, Operator, flags=f)
@@ -1975,23 +1997,6 @@ def test_powers_diagonal():
 # Test broadcasting operators
 #=============================
 
-def test_broadcasting_as_strided():
-    shapes = {'leftward': (2, 4, 3, 4, 2, 2),
-              'rightward': (3, 2, 2, 3, 1, 2)}
-
-    def func(b):
-        o = BroadcastingOperator(np.arange(6).reshape((3, 1, 2, 1)),
-                                 broadcast=b)
-        s = shapes[b]
-        if b == 'leftward':
-            v = o.data*np.ones(s)
-        else:
-            v = (o.data.T * np.ones(s, int).T).T
-        assert_eq(o._as_strided(s), v)
-    for b in ('rightward', 'leftward'):
-        yield func, b
-
-
 def test_diagonal1():
     data = (0., 1., [0, 0], [1, 1], 2, [2, 2], [0, 1], [-1, -1], [-1, 1],
             [2, 1])
