@@ -6,7 +6,7 @@ import pyoperators
 from numpy.testing import assert_allclose, assert_equal, assert_raises
 from pyoperators import (
     Operator, BlockColumnOperator, BlockDiagonalOperator, DenseOperator,
-    DiagonalOperator, MaskOperator)
+    DiagonalOperator, IdentityOperator, MaskOperator)
 from pyoperators.linear import (
     DegreesOperator, DiagonalNumexprOperator, DifferenceOperator,
     IntegrationTrapezeOperator, PackOperator, RadiansOperator,
@@ -140,12 +140,24 @@ def test_packing():
         assert_equal(p.T.broadcast, p.broadcast)
         assert_equal(p.T(expected_), masking(x_))
 
+        up = p.T * p
+        assert_is_instance(up, MaskOperator)
+        assert_equal(up(x_), p.T(p(x_)))
+        pu = p * p.T
+        assert_is_instance(pu, IdentityOperator)
+
         u = UnpackOperator(valid, broadcast=broadcast)
         assert_is_type(u.T, PackOperator)
         assert_equal(u.T.broadcast, u.broadcast)
         assert_equal(u(expected_), masking(x_))
         assert_equal(u.T(x_), expected_)
 
+        up = u * u.T
+        assert_is_instance(up, MaskOperator)
+        assert_equal(up(x_), u(u.T(x_)))
+        pu = u.T * u
+        assert_is_instance(pu, IdentityOperator)
+
     for valid, x in zip(valids, xs):
         for shape in shapes:
             for broadcast in broadcasts:
